@@ -28,6 +28,9 @@ TICKET_CONNECTOR_CONFIG_DEFAULT = {
         'SessionCreate': {'RequestMethod': 'POST',
                           'Route': '/Session',
                           'Result': 'SessionID'},
+        'SessionGet': {'RequestMethod': 'GET',
+                       'Route': '/Session/:SessionID',
+                       'Result': 'SessionData'},
         'TicketCreate': {'RequestMethod': 'POST',
                          'Route': '/Ticket',
                          'Result': 'TicketID'},
@@ -151,13 +154,11 @@ class Article(object):
         if self.aid != 0:
             _len = len(self.attachments)
             if _len == 0:
-                return "<ArticleID: {1}>".format(self.__class__.__name__, self.aid)
+                return "<ArticleID: {0}>".format(self.aid)
             elif _len == 1:
-                return "<ArticleID: {1} (1 Attachment)>".format(self.__class__.__name__,
-                                                                self.aid)
+                return "<ArticleID: {0} (1 Attachment)>".format(self.aid)
             else:
-                return "<ArticleID: {1} ({2} Attachments)>".format(self.__class__.__name__,
-                                                                   self.aid, _len)
+                return "<ArticleID: {0} ({1} Attachments)>".format(self.aid, _len)
         else:
             return "<{0}>".format(self.__class__.__name__)
 
@@ -982,9 +983,16 @@ class Client(object):
     GenericInterface::Operation::Session::SessionCreate
         * session_check_is_valid
         * session_create
+        * session_get
         * session_restore_or_set_up_new  # try to get session_id from a (json) file on disc
     """
 
+    @deprecation.deprecated(deprecated_in="0.10.0", removed_in="2.0", current_version=__version__,
+                            details="This method was implemented with a \"dirty\" workaround and "
+                                    "should not be called anymore. Use Client.session_get() "
+                                    "instead. ATTENTION: Using session_get() requires the OTRS "
+                                    "route for HTTP GET /Session to be configured  (which is/was "
+                                    "not the default).")
     def session_check_is_valid(self, session_id=None):
         """check whether session_id is currently valid
 
@@ -1008,7 +1016,7 @@ class Client(object):
         # TODO 2016-04-13 (RH): Is there a nicer way to check whether session is valid?!
         payload = {"SessionID": session_id}
 
-        response = self._send_request(payload, ticket_id=self.session_validation_ticket_id)
+        response = self._send_request(payload, data_id=self.session_validation_ticket_id)
         return self._parse_and_validate_response(response)
 
     def session_create(self):
@@ -1043,6 +1051,74 @@ class Client(object):
         self.session_id_store.value = self.result_json['SessionID']
         return True
 
+    def session_get(self, session_id=None):
+        """get/check/validate a Session ID
+
+        Returns:
+            **bool**: **True** if successful, otherwise **False**.
+
+        .. note::
+            Uses HTTP Method: GET
+
+        """
+        self.operation = "SessionGet"
+
+        if not session_id:
+            raise ArgumentMissingError("session_id")
+
+        payload = {"SessionID": session_id}
+
+        response = self._send_request(payload, data_id=session_id)
+        return self._parse_and_validate_response(response)
+
+    def session_restore_or_create(self):
+        """Try to restore Session ID from file otherwise create new one and save to file
+
+        Raises:
+            SessionCreateError
+            SessionIDFileError
+
+        .. note::
+            Session ID is recorded in self.session_id_store.value (**non persistently**)
+
+        .. note::
+            Session ID is **saved persistently** to file: *self.session_id_store.file_path*
+
+        Returns:
+            **bool**: **True** if successful, otherwise **False**.
+        """
+        # try to read session_id from file
+        self.session_id_store.value = self.session_id_store.read()
+
+        if self.session_id_store.value:
+            # got one.. check whether it's still valid
+            if self.session_get(self.session_id_store.value):
+                log.info("Using valid Session ID "
+                         "from ({0})".format(self.session_id_store.file_path))
+                return True
+
+        # got no (valid) session_id; clean store
+        self.session_id_store.write("")
+
+        # and try to create new one
+        if not self.session_create():
+            raise SessionCreateError("Failed to create a Session ID!")
+
+        # save new created session_id to file
+        if not self.session_id_store.write(self.result_json['SessionID']):
+            raise IOError("Failed to save Session ID to file!")
+        else:
+            log.info("Saved new Session ID to file: "
+                     "{0}".format(self.session_id_store.file_path))
+            return True
+
+    @deprecation.deprecated(deprecated_in="0.10.0", removed_in="2.0", current_version=__version__,
+                            details="This method uses session_check_is_valid which was "
+                                    "implemented with a \"dirty\" workaround and should not be "
+                                    "called anymore. Use Client.session_restore_or_create() "
+                                    "instead. ATTENTION: Using that also switches to "
+                                    "session_get() which requires the OTRS route for HTTP GET "
+                                    "/Session to be configured  (which is/was not the default).")
     def session_restore_or_set_up_new(self):
         """Try to restore Session ID from file otherwise create new one and save to file
 
@@ -1843,11 +1919,11 @@ class Client(object):
         else:
             return False
 
-    def _build_url(self, ticket_id=None):
+    def _build_url(self, data_id=None):
         """build url for request
 
         Args:
-            ticket_id (optional[int])
+            data_id (optional[int])
 
         Returns:
             **str**: The complete URL where the request will be send to.
@@ -1861,11 +1937,17 @@ class Client(object):
             route_arg = route_split[1]
 
             if route_arg == "TicketID":
-                if not ticket_id:
+                if not data_id:
                     raise ValueError("TicketID is None but Route requires "
                                      "TicketID: {0}".format(route))
                 self._url = ("{0}{1}{2}{3}{4}".format(
-                    self.baseurl, self.webservice_path, self.ws_ticket, route, ticket_id))
+                    self.baseurl, self.webservice_path, self.ws_ticket, route, data_id))
+            elif route_arg == "SessionID":
+                if not data_id:
+                    raise ValueError("SessionID is None but Route requires "
+                                     "SessionID: {0}".format(route))
+                self._url = ("{0}{1}{2}{3}{4}".format(
+                    self.baseurl, self.webservice_path, self.ws_ticket, route, data_id))
         else:
             if route in self.routes_ticket:
                 self._url = ("{0}{1}{2}{3}".format(
@@ -1879,12 +1961,12 @@ class Client(object):
 
         return self._url
 
-    def _send_request(self, payload=None, ticket_id=None):
+    def _send_request(self, payload=None, data_id=None):
         """send the API request using the *requests.request* method
 
         Args:
             payload (dict)
-            ticket_id (optional[dict])
+            data_id (optional[dict])
 
         Raises:
             OTRSHTTPError:
@@ -1900,7 +1982,7 @@ class Client(object):
 
         self._result_type = self.ws_config[self.operation]["Result"]
 
-        url = self._build_url(ticket_id)
+        url = self._build_url(data_id)
 
         http_method = self.ws_config[self.operation]["RequestMethod"]
 
@@ -2006,6 +2088,21 @@ class Client(object):
                 self.result = self.result_json['TicketID']
                 return True
 
+        # now handle SessionGet operation
+        if self.operation in ["SessionGet"]:
+            _session_data = self.result_json.get(self._result_type, None)
+            if _session_data:  # received SessionData -> Session ID is valid
+                self._result_error = False
+                self.result = self.result_json[self._result_type]
+                return True
+            elif self.result_json["Error"]["ErrorCode"] == "SessionGet.SessionInvalid":
+                return False
+            else:
+                raise APIError("Failed to access OTRS API.\n"
+                               "OTRS Error Code: {0}\nOTRS Error Message: {1}"
+                               "".format(self.result_json["Error"]["ErrorCode"],
+                                         self.result_json["Error"]["ErrorMessage"]))
+
         # handle Link operations; Add, Delete, DeleteAll return: {"Success":1}
         if self.operation in ["LinkAdd", "LinkDelete", "LinkDeleteAll"]:
             if self.result_json.get("Success", None) == 1:
